#!/bin/sh

#	tftpbak - Copyleft 2002, 2003, 2004 - Garry W. Cook
#		garry@cookbros.net

#	This program is free software; you can redistribute it and/or modify
#	it under the terms of the GNU General Public License as published by
#	the Free Software Foundation; either version 2 of the License, or
#	(at your option) any later version.
#
#	This program is distributed in the hope that it will be useful,
#	but WITHOUT ANY WARRANTY; without even the implied warranty of
#	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#	GNU General Public License for more details.
#
#	You should have received a copy of the GNU General Public License
#	along with this program; if not, write to the Free Software
#	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

#	The tftpbak script uses SNMPSET commands to download device configuration
#	files to a tftp server. In some cases, device configurations are also
#	written to the NVRAM, so that unsaved changes are not lost in the case of
#	an unscheduled reload.
#
# 	Variables that will need to be edited to suit your site are in CAPS and 
# 	surrounded by angle brackets. (eg. <VARIABLE>)


# SNMP Community string for Read-Write access to devices
# Insert your SNMP Community String on the line below.
RWSTRING=<SNMP_RW_COMMUNITY_STRING>

# SNMP Timeout Value
# Value is seconds, feel free to change this to meet your needs.
TIMEOUT=60

# IP Address of backup server
# Insert your TFTP Server's IP Address on the line below.
SERVER=<TFTP.SERVER.IP.ADDRESS>

# We run the 'tftpbak' script from CRON daily at 45 minutes past midnight
# with the following line in crontab:
#	45 00 * * * root cd /usr/local/sbin/ && ./tftpbak
#
# In crontab, the MAILTO variable is set to root, so root will receive an email
# with progress, hence the echo's in the code below.

echo
echo Message from <SERVER_NAME>
echo Output of script /usr/local/sbin/tftpbak
echo
echo
echo +++++++++++++
echo   <ROUTER_SECTION_TITLE> 
echo +++++++++++++
echo
echo Writing <ROUTER_NAME> configuration to TFTP server and NVRAM.

#	The following code has been used on Cisco Router Series 1600, 1700, 2500,
#	2600, & 3600 with IOS>=11.3. This is also known to work with Cisco Switch
#	Series 2950, 3500, 3550, and a 4006 running IOS on a Supervisor 3 Engine.
#	This has not been tested on any other devices.

snmpset -t $TIMEOUT <IP.ADDRESS.OF.DEVICE> $RWSTRING .1.3.6.1.4.1.9.2.1.55.$SERVER s <FILENAME_OF_CONFIG>
snmpset -t $TIMEOUT <IP.ADDRESS.OF.DEVICE> $RWSTRING .1.3.6.1.4.1.9.2.1.54.0 i 1


echo
echo ++++++++++++++++++++++++
echo   <SWITCH_SECTION_TITLE> 
echo ++++++++++++++++++++++++
echo
echo Writing <SWITCH_NAME> configuration to TFTP server and NVRAM.

# The Cisco 4000 Series Switches (CatOS) switches use the CISCO-STACK-MIB.
# The following OID gives the agent the IP address/hostname of the TFTP server to interact with:
snmpset -t $TIMEOUT <IP.ADDRESS.OF.SWITCH> $RWSTRING .1.3.6.1.4.1.9.5.1.5.1.0 s $SERVER
# The next OID assigns the name of the file to be used:
snmpset -t $TIMEOUT <IP.ADDRESS.OF.SWITCH> $RWSTRING .1.3.6.1.4.1.9.5.1.5.2.0 s <FILENAME_OF_CONFIG>
# Which module's code/config are we working with? This is usually Module 1.
snmpset -t $TIMEOUT <IP.ADDRESS.OF.SWITCH> $RWSTRING .1.3.6.1.4.1.9.5.1.5.3.0 i 1
# What action will be performed?
# 	2) Upload CFG to device from TFTP Server
#	3) Download CFG from device to TFTP Server
#	4) Download Software from device to TFTP Server
#	5) Upload Software to device from TFTP Server
#	6) Download Firmware from device to TFTP Server
#	7) Upload Firmware to device from TFTP Server
snmpset -t $TIMEOUT <IP.ADDRESS.OF.SWITCH> $RWSTRING .1.3.6.1.4.1.9.5.1.5.4.0 i 3

# To summarize the above: The CatOS switches use the CISCO-STACK-MIB.
echo
echo Writing <SWITCH_NAME> configuration to TFTP server and NVRAM.
snmpset -t $TIMEOUT <IP.ADDRESS.OF.SWITCH> $RWSTRING .1.3.6.1.4.1.9.5.1.5.1.0 s $SERVER
snmpset -t $TIMEOUT <IP.ADDRESS.OF.SWITCH> $RWSTRING .1.3.6.1.4.1.9.5.1.5.2.0 s <FILENAME_OF_CONFIG>
snmpset -t $TIMEOUT <IP.ADDRESS.OF.SWITCH> $RWSTRING .1.3.6.1.4.1.9.5.1.5.3.0 i 1
snmpset -t $TIMEOUT <IP.ADDRESS.OF.SWITCH> $RWSTRING .1.3.6.1.4.1.9.5.1.5.4.0 i 3
echo

#	There are two EXPECT scripts called upon to download configs from HP Switches.
#	'tftp4100' is known to work with HP Series Switches 4100, 2650, & 2524.
#	'tftp4000' works with HP 4000M Series Switches
#	These scripts should live in the same directory as 'tftpbak'.
echo
echo Writing <SWITCH_NAME> configuration to TFTP server.
./tftp4100 <IP.ADDRESS.OF.SWITCH> <FILENAME_OF_CONFIG>
echo
echo Writing <SWITCH_NAME> configuration to TFTP server.
./tftp4000 <IP.ADDRESS.OF.SWITCH> <FILENAME_OF_CONFIG>
echo

